@@ -1,5 +1,5 @@
 from webob import Request, Response
-from BBWebFw.FileRenderer import Template
+#from BBWebFw.FileRenderer import Template
 import os, sys, re, datetime
 from gunicorn.app.wsgiapp import run as boot
 
@@ -8,10 +8,11 @@ class api:
     docstring
     """
 
-    def __init__(self, name, server):
+    def __init__(self, name, server, hostAddr="0.0.0.0:80"):
         self.urls = {}
         self.server = server
         self.name = name
+        self.hostAddr = hostAddr
         self.out404 = '<!DOCTYPE html>\n<html lang="en">\n<head>\n    <meta charset="UTF-8">\n    <meta name="viewport" content="width=device-width, initial-scale=1.0">\n    <title>Document</title>\n</head>\n<body>\n    Hello\n</body>\n</html>'
         self.error = {"urlcatcherexists" : "ERR:URL_CATCHER_ALREADY_EXISTS"}
     
@@ -21,24 +22,42 @@ class api:
         response = self.handle_request(request)
         return response(environ, start_response)
 
+    def getFileType(self, f):
+        self.extList={
+                    ".png": "image/png",
+                    ".jpg": "image/jpg",
+                    ".jpeg": "image/jpeg",
+                    ".ico": "image/ico",
+                    ".txt": "text/txt",
+                    ".html": "image/text",
+                    ".css": "stylesheet/text",
+                }
+        return self.extList[os.path.splitext(f)[1]]
+
     def handle_request(self, request):
         #user_agent = request.environ.get('HTTP_USER_AGENT')
         response = Response()
         response.status_code = 200
         response.text = "Blank"
         with open("access-log.txt", "wb") as f:
-            f.writeline(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200').encode())
+            f.write(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200').encode())
         
         handler = self.find_handler(request)
 
         if handler is not None:
             handler(response)
         else:
+            print(self.getFileType(request.path)[1])
             try:
-                return Response(body=open(request.path, "rb"))
-            except e:
+                try:
+                    return Response(body=(open(os.path.join(self.staticDir,"static"+request.path), "rb")).read())
+                except Exception as e:
+                    print(e)
+                    self.err404(response)
+            except Exception as e:
                 print(e)
-                self.err404(response)
+                response.text = "Well My Work Was Not Clean Enough, but...<br><b>Thats A Server Problem</b>"
+                response.status_code = 500
         return response
 
     def catchURL(self, path):
@@ -69,10 +88,11 @@ class api:
         else:
             raise Exception("Invalid Error Code")
 
+    def setStaticDir(self, dir_):
+        self.staticDir = dir_
+
     def run(self, app):
-        print("running at 127.0.0.1 at port 8000")
-        host = "127.0.0.1"
-        port = 6000
+        print("run")
 
         if (self.name).endswith(".py"):
             self.fname = self.name
@@ -80,6 +100,8 @@ class api:
         else:
             self.fname = self.name + ".py"
         
-        sys.argv = [re.sub(r'(-script\.pyw|\.exe)?$', '', "env/bin/gunicorn"),self.name+':'+ app]
+        sys.argv = [re.sub(r'(-script\.pyw|\.exe)?$', '', "env/bin/gunicorn"),self.name+':'+ app, "-b", self.hostAddr]
         print(sys.argv)
         sys.exit(boot())
+        
+        
\ No newline at end of file
